==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_functions/mp9501_001/CUSTOMFIELDREQ.java <==

package net.datastream.schemas.mp_functions.mp9501_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ENTITYNAME" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element name="VALUECODE" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="REQTYPE" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entityname",
    "organizationid",
    "classid",
    "valuecode",
    "reqtype"
})
@XmlRootElement(name = "CUSTOMFIELDREQ")
public class CUSTOMFIELDREQ {

    @XmlElement(name = "ENTITYNAME", required = true)
    protected String entityname;
    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "VALUECODE")
    protected String valuecode;
    @XmlElement(name = "REQTYPE")
    protected String reqtype;

    /**
     * Obtient la valeur de la propriété entityname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYNAME() {
        return entityname;
    }

    /**
     * Définit la valeur de la propriété entityname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYNAME(String value) {
        this.entityname = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété valuecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVALUECODE() {
        return valuecode;
    }

    /**
     * Définit la valeur de la propriété valuecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVALUECODE(String value) {
        this.valuecode = value;
    }

    /**
     * Obtient la valeur de la propriété reqtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREQTYPE() {
        return reqtype;
    }

    /**
     * Définit la valeur de la propriété reqtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREQTYPE(String value) {
        this.reqtype = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp9501_001/CUSTOMFIELDREQ.java <==

package net.datastream.schemas.mp_functions.mp9501_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ENTITYNAME" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element name="VALUECODE" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="REQTYPE" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entityname",
    "organizationid",
    "classid",
    "valuecode",
    "reqtype"
})
@XmlRootElement(name = "CUSTOMFIELDREQ")
public class CUSTOMFIELDREQ {

    @XmlElement(name = "ENTITYNAME", required = true)
    protected String entityname;
    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "VALUECODE")
    protected String valuecode;
    @XmlElement(name = "REQTYPE")
    protected String reqtype;

    /**
     * Gets the value of the entityname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYNAME() {
        return entityname;
    }

    /**
     * Sets the value of the entityname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYNAME(String value) {
        this.entityname = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the valuecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVALUECODE() {
        return valuecode;
    }

    /**
     * Sets the value of the valuecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVALUECODE(String value) {
        this.valuecode = value;
    }

    /**
     * Gets the value of the reqtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREQTYPE() {
        return reqtype;
    }

    /**
     * Sets the value of the reqtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREQTYPE(String value) {
        this.reqtype = value;
    }

}
